
# Zigbee2MQTT
This module installs and runs Zigbee2MQTT.

## Usage
```
define z2m fhempy zigbee2mqtt
```

Wait afterwards a few minutes after the installation finishs. This can take up to 10 minutes or sometimes even more.

Go to the Zigbee2MQTT room to see the Zigbee2MQTT frontend.

### Start
```
set z2m start
```

### Stop
```
set z2m stop
```

### Update
```
set z2m update
```
